var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var svg_sprite_exports = {};
__export(svg_sprite_exports, {
  default: () => svg_sprite_default
});
module.exports = __toCommonJS(svg_sprite_exports);
var fs = __toESM(require("node:fs"));
var path = __toESM(require("node:path"));
var import_svg_parser = __toESM(require("../libs/svg-parser"));
let rootFolder = "";
let outputFolder = "";
let outputFilename = "index.tsx";
let template = null;
let namedComponents = false;
function svg_sprite_default(args) {
  if (args.length >= 2) {
    rootFolder = normalizeFolder(args[0]);
    let outputPath = args[1];
    if (outputPath.endsWith(".tsx")) {
      outputFolder = path.dirname(outputPath);
      outputFilename = path.basename(outputPath);
    } else {
      outputFolder = normalizeFolder(outputPath);
    }
    for (let i = 2; i < args.length; i++) {
      if (args[i].startsWith("--template=")) {
        const templateFilename = args[i].substring("--template=".length);
        template = fs.readFileSync(templateFilename, "utf8");
      } else if (args[i] === "--components") {
        namedComponents = true;
      }
    }
  } else {
    console.log("Usage: npx rmx-cli svg-sprite SOURCE_FOLDER OUTPUT_PATH [--components] [--template=TEMPLATE_FILE]");
    console.log("  SOURCE_FOLDER: folder containing .svg files");
    console.log("  OUTPUT_PATH: output path for sprite file and components");
    console.log("    if OUTPUT_PATH ends with .tsx, then use this as the base filename");
    console.log("   --components: generate named components for each icon");
    console.log("  --template=TEMPLATE_FILE: use custom template file");
    process.exit(1);
  }
  generateSprites(rootFolder);
}
function normalizeFolder(folder) {
  let fullPath = path.resolve(folder);
  let normalized = fullPath.replace(process.cwd(), "").substring(1);
  return normalized;
}
function generateSprites(folder) {
  const svgFiles = fs.readdirSync(folder).filter((file) => file.endsWith(".svg")).map((file) => path.join(folder, file));
  if (svgFiles.length > 0) {
    generateSprite(folder, svgFiles);
  }
  const folders = fs.readdirSync(folder, { withFileTypes: true }).filter((dirent) => dirent.isDirectory()).map((dirent) => path.join(folder, dirent.name));
  folders.forEach((folder2) => {
    generateSprites(folder2);
  });
}
function generateSprite(folder, files) {
  const spriteOutputFolder = folder.replace(rootFolder, outputFolder);
  const spriteOutput = path.join(spriteOutputFolder, path.basename(outputFilename, ".tsx") + ".svg");
  console.log(`\u{1F4DD} Generating sprite for ${folder}`);
  if (!fs.existsSync(spriteOutputFolder)) {
    fs.mkdirSync(spriteOutputFolder, { recursive: true });
  }
  const strip = true;
  const trim = false;
  let { svgElement } = import_svg_parser.default.iterateFiles(files, strip, trim);
  svgElement = import_svg_parser.default.wrapInSvgTag(svgElement);
  import_svg_parser.default.writeIconsToFile(spriteOutput, svgElement);
  generateReactComponent(spriteOutputFolder, files);
}
function generateReactComponent(spriteOutputFolder, files) {
  let icons = files.map((file) => path.basename(file, ".svg"));
  const spritePath = path.basename(outputFilename, ".tsx") + ".svg";
  let component = template != null ? template : `
import { type SVGProps } from "react";
import href from "./${spritePath}";
export { href };

export default function Icon({ icon, ...props}: SVGProps<SVGSVGElement> & { icon: IconName }) {
  return (
    <svg {...props}>
      <use href={\`\${href}#\${icon}\`} />
    </svg>
  );
}
`;
  component += `
type IconName =
${icons.map((icon) => `  | "${icon}"`).join("\n")}
`;
  icons.forEach((icon) => console.log(`\u2705 ${icon}`));
  if (namedComponents) {
    icons.forEach((icon) => {
      const componentName = icon.replace(/(^|-)([a-z0-9])/g, (g) => g.at(-1).toUpperCase());
      component += `
export const ${componentName}Icon = (props: SVGProps<SVGSVGElement>) => <Icon icon="${icon}" {...props} />;`;
    });
  }
  fs.writeFileSync(path.join(spriteOutputFolder, outputFilename), component.trim());
  console.log();
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
