const fs = require("fs");
const path = require("path");
const svgParserLib = {
  fgRed: "\x1B[31m",
  fgGreen: "\x1B[32m",
  fgYellow: "\x1B[33m",
  fgReset: "\x1B[0m",
  createSymbol: (file, name) => {
    if (!file || !name) {
      throw new Error("No file found at " + name);
    } else if (!file.includes("<svg")) {
      throw new Error("No SVG node found in " + name);
    }
    let symbolEl = file.replace(/<\?xml.*?\?>/, "").replace(/ id=".*?"/, "").replace(/ version=".*?"/, "").replace(/ xmlns=".*?"/, "").replace(/ xmlns:xlink=".*?"/, "").replace("<svg", `<symbol id="${name}"`).replace("</svg>", "</symbol>\n");
    return symbolEl;
  },
  stripProperties: (svg) => {
    const strokeFill = /\s+(stroke|fill)="((?!(none|currentColor)).*?)"/gim;
    const widthHeight = /\s+(width|height)=".*?"/gim;
    return svg.replace(strokeFill, ' $1="currentColor"').replace(widthHeight, "");
  },
  makeSolid: (svg) => {
    return svg.replace(/fill="none"/g, 'fill="currentColor"');
  },
  removeWhitespaces: (svg) => {
    return svg.replace(/\n/g, "").replace(/[\t ]+\</g, "<").replace(/\>[\t ]+\</g, "><").replace(/\>[\t ]+$/g, ">");
  },
  wrapInSvgTag: (elements) => {
    return `<?xml version="1.0" encoding="UTF-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="0" height="0">
${elements}</svg>
`;
  },
  iterateFiles: (files, strip, trim) => {
    let svgElement = "";
    let elementsChanged = 0;
    files.forEach((file) => {
      let name = path.basename(file, ".svg");
      try {
        let svg = fs.readFileSync(file, "utf8");
        let symbolEl = svgParserLib.createSymbol(svg, name);
        if (strip) {
          symbolEl = svgParserLib.stripProperties(symbolEl);
        }
        svgElement += symbolEl;
        elementsChanged++;
      } catch (e) {
        console.warn(svgParserLib.fgRed + "Could not parse", name, "because of error:" + svgParserLib.fgReset, e.message, "- file skipped!");
      }
    });
    if (trim) {
      svgElement = svgParserLib.removeWhitespaces(svgElement);
    }
    return { svgElement, elementsChanged };
  },
  readFile: (fileObj) => {
    return fs.readFileSync(fileObj.path, "utf8");
  },
  writeIconsToFile: (fullFileName, outputString) => {
    fs.writeFileSync(fullFileName, outputString, "utf8");
  },
  readDirectory: (dirname, filetype) => {
    return new Promise((resolve, reject) => {
      let fileList = [];
      fs.readdir(dirname, (error, files) => {
        if (error) {
          reject(error);
        } else {
          files.forEach((file) => {
            if (file.includes(filetype)) {
              fileList.push(file);
            }
          });
          resolve(fileList);
        }
      });
    });
  }
};
module.exports = svgParserLib;
